@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: acpi-linux.c,v 1.7.2.2 2004/01/04 16:56:35 kevinv Exp $
+ $Id: acpi-linux.c,v 1.8 2003/10/22 22:01:18 kevinv Exp $
  */
 
 /*
@@ -294,12 +294,31 @@ void acpi_linux_cleanup(struct acpi_info * acpiinfo)
 /* Given a string event from the ACPI system, returns the type
  * of event if we're interested in it.  str is updated to point
  * to the next event. */
-static int parse_acpi_event(GString *buffer)
+static int parse_acpi_event(char * event, char ** str)
 {
+  char * end;
+  char * tok[4];
+  int i;
+
+  end = strchr(event, '\n');
+  if (!end)
+    return ACPI_EVENT_DONE;
+
+  *end = '\0';
+  *str = end + 1;
+
+  tok[0] = event;
+  for (i=0; i < 3; i++) {
+    tok[i+1] = strchr(tok[i], ' ');
+    if (!tok[i+1])
+      return ACPI_EVENT_IGNORE;
+    *(tok[i+1]) = '\0';
+    tok[i+1]++;
+  }
   
-  if (strstr(buffer->str, "ac_adapter"))
+  if (!strcmp(tok[0], "ac_adapter"))
     return ACPI_EVENT_AC;
-  if (strstr(buffer->str, "battery") )
+  if (!strcmp(tok[0], "battery") && atoi(tok[2]) == 81)
     return ACPI_EVENT_BATTERY_INFO;
 
   return ACPI_EVENT_IGNORE;
@@ -311,18 +330,16 @@ static int parse_acpi_event(GString *buffer)
  * by select(). */
 gboolean acpi_process_event(struct acpi_info * acpiinfo)
 {
-    gsize i;
+    int i;
     int evt;
     char * s;
-    /*    char str[1024];*/
+    char str[256];
     gboolean result = FALSE;
-    GString *buffer;
-    GError *gerror=NULL;
-    buffer=g_string_new(NULL);
-    g_io_channel_read_line_string   ( acpiinfo->channel,buffer,&i,&gerror);
 
-    
-    evt = parse_acpi_event(buffer);
+    i = read(acpiinfo->event_fd, str, sizeof(str)-1);
+    str[i] = '\0';
+    s = str;
+    while ((evt = parse_acpi_event(s, &s)) != ACPI_EVENT_DONE) {
       switch (evt) {
         case ACPI_EVENT_AC:
           update_ac_info(acpiinfo);
@@ -333,7 +350,7 @@ gboolean acpi_process_event(struct acpi_info * acpiinfo)
           result = TRUE;
           break;
       }
-    
+    }
 
     return result;
 }
