@@ -1,4 +1,4 @@
-/* $Id: weather.c,v 1.55.2.2 2003/07/16 19:46:09 baddog Exp $ */
+/* $Id: weather.c,v 1.65 2003/12/07 16:11:21 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -138,8 +138,9 @@ static const gchar *wind_direction_str[] = {
 
 const gchar *weather_wind_direction_string (WeatherWindDirection wind)
 {
-	if (wind < 0 ||
-	    wind >= (sizeof (wind_direction_str) / sizeof (char *)))
+        if (wind < 0)
+	        return _("Unknown");
+	if (wind >= (sizeof (wind_direction_str) / sizeof (char *)))
 		return _("Invalid");
 
 	return _(wind_direction_str[(int)wind]);
@@ -1051,7 +1052,7 @@ static void iwin_finish_read(GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
     }
     else if (result != GNOME_VFS_OK) {
 	g_print("%s", gnome_vfs_result_to_string(result));
-        g_warning(_("Failed to get IWIN data.\n"));
+        g_warning("Failed to get IWIN data.\n");
     } else {
 	gnome_vfs_async_read(handle, body, DATA_SIZE - 1, iwin_finish_read, info);
 
@@ -1095,7 +1096,7 @@ static void iwin_finish_open (GnomeVFSAsyncHandle *handle, GnomeVFSResult result
 
     if (result != GNOME_VFS_OK) {
         /* forecast data is not really interesting anyway ;) */
-	  g_warning(_("Failed to get IWIN forecast data.\n")); 
+	  g_warning("Failed to get IWIN forecast data.\n"); 
         info->iwin_handle = NULL;
         requests_done_check (info);
         g_free (body);
@@ -1294,7 +1295,7 @@ static void met_finish_read(GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
 	g_print("%s", gnome_vfs_result_to_string(result));
 	info->met_handle = NULL;
 	requests_done_check (info);
-        g_warning(_("Failed to get Met Office data.\n"));
+        g_warning("Failed to get Met Office data.\n");
     } else {
 	gnome_vfs_async_read(handle, body, DATA_SIZE - 1, met_finish_read, info);
 
@@ -1328,7 +1329,7 @@ static void met_finish_open (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
     g_return_if_fail(loc != NULL);
 
     if (result != GNOME_VFS_OK) {
-        g_warning(_("Failed to get Met Office forecast data.\n"));
+        g_warning("Failed to get Met Office forecast data.\n");
         info->met_handle = NULL;
         requests_done_check (info);
         g_free (body);
@@ -1472,7 +1473,7 @@ static void wx_finish_open (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
     g_return_if_fail(loc != NULL);
 
     if (result != GNOME_VFS_OK) {
-        g_warning(_("Failed to get radar map image.\n"));
+        g_warning("Failed to get radar map image.\n");
         info->wx_handle = NULL;
         requests_done_check (info);
         g_free (body);
@@ -1545,18 +1546,20 @@ gboolean _weather_info_fill (GWeatherApplet *applet, WeatherInfo *info, WeatherL
     }
 
     /* Defaults (just in case...) */
+    /* Well, no just in case anymore.  We may actually fail to fetch some
+     * fields. */
     info->units = UNITS_IMPERIAL;
     info->update = 0;
-    info->sky = SKY_CLEAR;
+    info->sky = -1;
     info->cond.significant = FALSE;
     info->cond.phenomenon = PHENOMENON_NONE;
     info->cond.qualifier = QUALIFIER_NONE;
-    info->temp = 0;
-    info->dew = 0;
-    info->humidity = 0;
-    info->wind = WIND_VARIABLE;
-    info->windspeed = 0;
-    info->pressure = 0.0;
+    info->temp = -1000.0;
+    info->dew = -1000.0;
+    info->humidity = -1;
+    info->wind = -1;
+    info->windspeed = -1;
+    info->pressure = -1.0;
     info->visibility = -1.0;
     info->forecast = NULL;
     info->radar = NULL;
@@ -1631,17 +1634,17 @@ WeatherInfo *weather_info_config_read (PanelApplet *applet)
     info->location = weather_location_config_read(applet);
     info->units = (WeatherUnits)0;
     info->update = (WeatherUpdate)0;
-    info->sky = (WeatherSky)0;
+    info->sky = -1;
     info->cond.significant = FALSE;
     info->cond.phenomenon = (WeatherConditionPhenomenon)0;
     info->cond.qualifier = (WeatherConditionQualifier)0;
-    info->temp = 0;
-    info->dew = 0;
-    info->humidity = 0;
-    info->wind = (WeatherWindDirection)0;
-    info->windspeed = 0;
-    info->pressure = 0;
-    info->visibility = 0;
+    info->temp = -1000.0;
+    info->dew = -1000.0;
+    info->humidity = -1;
+    info->wind = -1;
+    info->windspeed = -1;
+    info->pressure = -1.0;
+    info->visibility = -1.0;
     info->forecast = g_strdup ("None");
     info->radar = NULL;  /* FIX */
     info->requests_pending = FALSE;
@@ -1791,6 +1794,8 @@ const gchar *weather_info_get_sky (WeatherInfo *info)
     g_return_val_if_fail(info != NULL, NULL);
     if (!info->valid)
         return "-";
+    if (info->sky < 0)
+	return "Unknown";
     return weather_sky_string(info->sky);
 }
 
@@ -1808,6 +1813,8 @@ const gchar *weather_info_get_temp (WeatherInfo *info)
     g_return_val_if_fail(info != NULL, NULL);
     if (!info->valid)
         return "-";
+    if (info->temp < -500.0)
+        return _("Unknown");
     g_snprintf(buf, sizeof (buf), "%.1f%s", info->temp, TEMP_UNIT_STR(info->units));
     return buf;
 }
@@ -1818,6 +1825,8 @@ const gchar *weather_info_get_dew (WeatherInfo *info)
     g_return_val_if_fail(info != NULL, NULL);
     if (!info->valid)
         return "-";
+    if (info->dew < -500.0)
+        return _("Unknown");
     g_snprintf(buf, sizeof (buf), "%.1f%s", info->dew, TEMP_UNIT_STR(info->units));
     return buf;
 }
@@ -1828,6 +1837,8 @@ const gchar *weather_info_get_humidity (WeatherInfo *info)
     g_return_val_if_fail(info != NULL, NULL);
     if (!info->valid)
         return "-";
+    if (info->humidity < 0.0)
+        return _("Unknown");
     g_snprintf(buf, sizeof (buf), "%d%%", info->humidity);
     return buf;
 }
@@ -1838,6 +1849,8 @@ const gchar *weather_info_get_wind (WeatherInfo *info)
     g_return_val_if_fail(info != NULL, NULL);
     if (!info->valid)
         return "-";
+    if (info->windspeed < 0.0 || info->wind < 0)
+        return _("Unknown");
     if (info->windspeed == 0.00) {
         strncpy(buf, _("Calm"), sizeof(buf));
 	buf[sizeof(buf)-1] = '\0';
@@ -1854,6 +1867,8 @@ const gchar *weather_info_get_pressure (WeatherInfo *info)
     g_return_val_if_fail(info != NULL, NULL);
     if (!info->valid)
         return "-";
+    if (info->pressure < 0.0)
+        return _("Unknown");
     g_snprintf(buf, sizeof (buf), "%.2f %s", info->pressure, PRESSURE_UNIT_STR(info->units));
     return buf;
 }
@@ -1885,11 +1900,22 @@ GdkPixmap *weather_info_get_radar (WeatherInfo *info)
 const gchar *weather_info_get_temp_summary (WeatherInfo *info)
 {
     static gchar buf[10];
+    const gchar *degree="h";
+    
     if (!info)
         return NULL;
-    if (!info->valid)
+    if (!info->valid || info->temp < -500.0)
         return "--";
-    g_snprintf(buf, sizeof (buf), "%d\302\260", (int)(info->temp + 0.5));
+    
+    if (!info->applet)
+      degree = "F";
+    else if (info->applet->gweather_pref.use_metric)                                   
+      degree = "C";                                               
+    else                                                                    
+      degree = "F";
+      
+   g_snprintf(buf, sizeof (buf), "%d\302\260%s",
+	      (int)lrint(info->temp), degree);
     
     return buf;
 }
@@ -2067,7 +2093,7 @@ void _weather_info_get_pixbuf (WeatherInfo *info, gboolean mini, GdkPixbuf **pix
                     idx = PIX_FOG;
                     break;
                 default:
-                    g_assert_not_reached();
+	            idx = PIX_UNKNOWN;
                 }
         } else {
             switch (sky) {
@@ -2083,7 +2109,7 @@ void _weather_info_get_pixbuf (WeatherInfo *info, gboolean mini, GdkPixbuf **pix
                 idx = PIX_CLOUD;
                 break;
             default:
-                g_assert_not_reached();
+	        idx = PIX_UNKNOWN;
             }
         }
     }
